@@ -1,11 +1,12 @@
 """
 Data Module
 """
-from __future__ import annotations
-from typing import List, Dict, Union
 from dataclasses import dataclass, field
+from typing import Dict, List, Union
+
 import numpy as np
-import pandas as pd
+from numpy import ndarray
+from pandas import DataFrame
 
 
 @dataclass
@@ -14,11 +15,11 @@ class Data:
     col_covs: List[str] = field(default_factory=list)
     col_weights: str = "weights"
     col_offset: str = "offset"
-    df: pd.DataFrame = field(default_factory=pd.DataFrame)
+    df: DataFrame = field(default_factory=DataFrame)
 
     def __post_init__(self):
         self.col_covs = list(set(self.col_covs).union({'intercept'}))
-        self.cols = self.col_covs + [self.col_weights, self.col_offset]
+        self.cols = self.col_covs + [self.col_weights, self.col_offset, "trim_weights"]
         if self.col_obs is not None:
             if isinstance(self.col_obs, str):
                 self.cols.insert(0, self.col_obs)
@@ -26,7 +27,7 @@ class Data:
                 self.cols = self.col_obs + self.cols
 
         if self.is_empty():
-            self.df = pd.DataFrame(columns=self.cols)
+            self.df = DataFrame(columns=self.cols)
         else:
             self.parse_df()
             self.fill_df()
@@ -40,7 +41,7 @@ class Data:
             if col not in self.df.columns:
                 raise ValueError(f"Missing columnn {col}.")
 
-    def parse_df(self, df: pd.DataFrame = None):
+    def parse_df(self, df: DataFrame = None):
         df = self.df if df is None else df
         self.df = df.loc[:, df.columns.isin(self.cols)].copy()
 
@@ -56,24 +57,25 @@ class Data:
             for col in cols:
                 if col not in self.df.columns:
                     self.df[col] = np.nan
+        self.df["trim_weights"] = 1.0
 
     def detach_df(self):
-        self.df = pd.DataFrame(columns=self.cols)
+        self.df = DataFrame(columns=self.cols)
 
-    def attach_df(self, df: pd.DataFrame):
+    def attach_df(self, df: DataFrame):
         self.parse_df(df)
         self.fill_df()
         self.check_cols()
 
-    def copy(self, with_df=False) -> Data:
-        df = self.df.copy() if with_df else pd.DataFrame(columns=self.cols)
+    def copy(self, with_df=False) -> "Data":
+        df = self.df.copy() if with_df else DataFrame(columns=self.cols)
         return Data(self.col_obs,
                     self.col_covs,
                     self.col_weights,
                     self.col_offset,
                     df)
 
-    def get_cols(self, cols: Union[List[str], str]) -> np.ndarray:
+    def get_cols(self, cols: Union[List[str], str]) -> ndarray:
         return self.df[cols].to_numpy()
 
     @property
@@ -81,24 +83,34 @@ class Data:
         return self.df.shape[0]
 
     @property
-    def obs(self) -> np.ndarray:
+    def obs(self) -> ndarray:
         if self.col_obs is None:
             raise ValueError("This data object does not contain observations.")
         return self.get_cols(self.col_obs)
 
     @property
-    def covs(self) -> Dict[str, np.ndarray]:
+    def covs(self) -> Dict[str, ndarray]:
         return self.df[self.col_covs].to_dict(orient="list")
 
     @property
-    def weights(self) -> np.ndarray:
+    def weights(self) -> ndarray:
         return self.get_cols(self.col_weights)
 
     @property
-    def offset(self) -> np.ndarray:
+    def offset(self) -> ndarray:
         return self.get_cols(self.col_offset)
 
-    def get_covs(self, col_covs: Union[List[str], str]) -> np.ndarray:
+    @property
+    def trim_weights(self) -> ndarray:
+        return self.get_cols("trim_weights")
+
+    @trim_weights.setter
+    def trim_weights(self, weights: Union[float, ndarray]):
+        if np.any(weights < 0.0) or np.any(weights > 1.0):
+            raise ValueError("trim_weights has to be between 0 and 1.")
+        self.df["trim_weights"] = weights
+
+    def get_covs(self, col_covs: Union[List[str], str]) -> ndarray:
         if not isinstance(col_covs, list):
             col_covs = [col_covs]
         return self.get_cols(col_covs)
