@@ -1,13 +1,16 @@
 """
 Parameter module
 """
-from typing import List, Tuple, Union
 from dataclasses import dataclass, field
+from typing import List, Tuple, Union
+
 import numpy as np
 from scipy.linalg import block_diag
-from .data import Data
-from .variable import Variable, SplineVariable
-from .function import SmoothFunction, fun_dict
+
+from regmod.data import Data
+from regmod.prior import LinearGaussianPrior, LinearUniformPrior
+from regmod.function import SmoothFunction, fun_dict
+from regmod.variable import SplineVariable, Variable
 
 
 @dataclass
@@ -16,12 +19,22 @@ class Parameter:
     variables: List[Variable] = field(repr=False)
     inv_link: Union[str, SmoothFunction] = field(repr=False)
     use_offset: bool = field(default=False, repr=False)
+    linear_gpriors: List[LinearGaussianPrior] = field(default_factory=list, repr=False)
+    linear_upriors: List[LinearUniformPrior] = field(default_factory=list, repr=False)
 
     def __post_init__(self):
         if isinstance(self.inv_link, str):
             self.inv_link = fun_dict[self.inv_link]
         assert isinstance(self.inv_link, SmoothFunction), \
             "inv_link has to be an instance of SmoothFunction."
+        assert all([isinstance(prior, LinearGaussianPrior) for prior in self.linear_gpriors]), \
+            "linear_gpriors has to be a list of LinearGaussianPrior."
+        assert all([isinstance(prior, LinearUniformPrior) for prior in self.linear_upriors]), \
+            "linear_upriors has to be a list of LinearUniformPrior."
+        assert all([prior.mat.shape[1] == self.size for prior in self.linear_gpriors]), \
+            "linear_gpriors size not match."
+        assert all([prior.mat.shape[1] == self.size for prior in self.linear_upriors]), \
+            "linear_upriors size not match."
 
     @property
     def size(self) -> int:
@@ -45,6 +58,9 @@ class Parameter:
             var.get_linear_uvec() if isinstance(var, SplineVariable) else np.empty((2, 0))
             for var in self.variables
         ])
+        if len(self.linear_upriors) > 0:
+            uvec = np.hstack([uvec] + [np.vstack([prior.lb, prior.ub])
+                                       for prior in self.linear_upriors])
         return uvec
 
     def get_linear_gvec(self) -> np.ndarray:
@@ -52,6 +68,9 @@ class Parameter:
             var.get_linear_gvec() if isinstance(var, SplineVariable) else np.empty((2, 0))
             for var in self.variables
         ])
+        if len(self.linear_gpriors) > 0:
+            gvec = np.hstack([gvec] + [np.vstack([prior.mean, prior.sd])
+                                       for prior in self.linear_gpriors])
         return gvec
 
     def get_linear_umat(self) -> np.ndarray:
@@ -59,6 +78,8 @@ class Parameter:
             var.get_linear_umat() if isinstance(var, SplineVariable) else np.empty((0, 1))
             for var in self.variables
         ])
+        if len(self.linear_upriors) > 0:
+            umat = np.vstack([umat] + [prior.mat for prior in self.linear_upriors])
         return umat
 
     def get_linear_gmat(self) -> np.ndarray:
@@ -66,6 +87,8 @@ class Parameter:
             var.get_linear_gmat() if isinstance(var, SplineVariable) else np.empty((0, 1))
             for var in self.variables
         ])
+        if len(self.linear_gpriors) > 0:
+            gmat = np.vstack([gmat] + [prior.mat for prior in self.linear_gpriors])
         return gmat
 
     def get_lin_param(self, coefs: np.ndarray, data: Data,
